@@ -33,8 +33,8 @@ class SensePushManager(object):
     def push_sync_done(self, job_name):
         message = build_sync_cmd_push_message(job_name)
         handler = PushDataHandler(database=message['db'], table=message['table'], queue_configs=self.queue_configs)
-        handler.insert_data(message)
-        sd.log_info("done push_sync_done {}".format(message))
+        handler.push_queue_message(message)
+        sd.log_info("done push_sync_done {} with queue={}".format(message, self.queue_configs))
 
     def _build_config(self, label, config, keys):
         if not label:
